#!/bin/sh
#
# source: http://roy.marples.name/dhcpcd/dhcpcd-3.2.3.tar.bz2
#
# maintainer: gmg (monpontet.gerard@neuf.fr)
#

#------------------Set Some Variables

soft='dhcpcd'
softversion='3.2.3'
packageversion='52.1'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.bz2"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

cd $buildir
rm -rf $src
tar -xvjf $srcpkg
rm -f $dest.tar.gz
rm -rf $dest

#-----------------build directories and copy the build script

mkdir -p $dest/install

#-----------------Make the slack-desc files

cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|' on
# the right side marks the last column you can put a character in.  You must make
# exactly 11 lines for the formatting to be correct.  It's also customary to
# leave one space after the ':'.

      |-----handy-ruler------------------------------------------------------|
dhcpcd: dhcpcd (DHCP client daemon)
dhcpcd:
dhcpcd: The DHCP client program dhcpcd is used to connect to a network by
dhcpcd: contacting a DHCP server.  dhcpcd gets an IP address and other
dhcpcd: information from a corresponding DHCP server, configures the network
dhcpcd: interface automatically, and tries to renew the lease time according
dhcpcd: to RFC2131 or RFC1541 depending on the command line option.
dhcpcd:
dhcpcd:
dhcpcd:
dhcpcd:
EODESC

#------------------Set correct permissions

cd $src

#disable DUID usage
echo "#undef ENABLE_DUID" >> config.h

chown -R root:root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 664 -exec chmod 644 {} \;

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

make
make install DESTDIR=$dest

mkdir $dest/usr/sbin
ln -sf /sbin/dhcpcd $dest/usr/sbin/dhcpcd

mkdir -p $dest/usr/man
mv $dest/usr/share/man $dest/usr
rmdir $dest/usr/share

gzip -9 $dest/usr/man/man?/*

( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null 
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

mkdir -p /$dest/var/lib/dhcpcd

#-------------------Prepare the documentation

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a README $dest/usr/doc/$soft-$softversion

mkdir -p $dest/usr/src/$soft-$softversion
cp -a $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.tgz
cd $buildir
md5sum $package.tgz > $package.md5